@@ -6,11 +6,25 @@ svn co http://svn.scipy.org/svn/scikits/trunk/delaunay
 (sudo) python setup.py install (--prefix=some/other/place)
 """
 
-__copyright__ = "(C) 2008 Rolv Erlend Bredesen and Simula Research Laboratory"
-__author__ = 'Rolv Erlend Bredesen <rolv@simula.no>'
-__date__ = '2008.11.12'
-__license__ = 'GNU LGPL Version 2.1.'
-
+# Copyright (C) 2008 Rolv Erlend Bredesen and Simula Research Laboratory
+#
+# This file is part of Viper.
+#
+# Viper is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# Viper is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with Viper. If not, see <http://www.gnu.org/licenses/>.
+#
+# First added:  2008-11-12
+# Last changed: 2008-11-12
 
 import numpy as N
 from scikits.delaunay import Triangulation # deb: python-scikits-delaunay
