@@ -1,10 +1,25 @@
 #!/usr/bin/env python
 
-__copyright__ = "(C) 2006-2009 Ola Skavhaug and Simula Research Laboratory"
-__license__   = "GNU LGPL Version 2.1."
+# Copyright (C) 2006-2011 Ola Skavhaug and Simula Research Laboratory
+#
+# This file is part of Viper.
+#
+# Viper is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# Viper is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with Viper. If not, see <http://www.gnu.org/licenses/>.
+
 __cite__      = """Ola Skavhaug, Viper Visualization Software,
 http://www.fenics.org/wiki/viper/"""
-__version__ = "0.4.7"
+__version__ = "1.0.0"
 
 r"""
 Viper
@@ -15,11 +30,9 @@ numpy arrays, and meshes that provide the two methods C{cells()} and
 C{coordinates()}. These methods should return numpy arrays specifying the
 node-element ordering and coordinates of the nodes, respectively.
 
-Copyright: %s
-Licence: %s
 Citation: %s
 
-""" % (__copyright__, __license__, __cite__)
+""" % __cite__
 
 """TODO: I need to generalize vtkgrid and darr such that multiples of these can
 be visualized at once. The fix is probably to construct some pipes (as Python
@@ -693,11 +706,35 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
                 if len(self._x_shape) == 1:
                     self.vtkgrid.GetCellData().SetScalars(self.darr)
 
+        if self.mode == "scalar_xy":
+            xVal = vtk.vtkFloatArray()
+            yVal = vtk.vtkFloatArray()
+
+            coords = self.mesh.coordinates()
+            for i in range(len(coords)):
+                xVal.InsertNextTuple1(coords[i])
+                yVal.InsertNextTuple1(x[i])
+
+            curve = vtk.vtkRectilinearGrid()
+            curve.SetDimensions(len(coords), 1, 1)
+            curve.SetXCoordinates(xVal)
+            curve.GetPointData().SetScalars(yVal)
+
+            xyplot = self.ren.GetViewProps().GetLastProp()
+            xyplot.RemoveAllInputs()
+            xyplot.AddInput(curve)
+
         if self.rescale and not self.mode == "scalar_xy":
             self.show_scalarbar()
             self.rescaleColors(self.x.min(), self.x.max())
         self.renWin.Render()
 
+        # Set the window title after the window is actually created to
+        # fix the problem with title not showing on OS X with Cocoa VTK
+        # and on Windows.
+        if self.frame is None:
+            self.renWin.SetWindowName(self.title)
+
         self.azimuth(self.azimuth_incr)
         # assumes that initial elevation is zero. If not the sum of
         # elevate steps might exceed 90 degrees, which is not good.
@@ -814,7 +851,6 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
         else:
             ren = vtk.vtkRenderer()
             renWin = vtk.vtkRenderWindow()
-            renWin.SetWindowName(self.title)
             renWin.AddRenderer(ren)
             renWin.SetSize(*self.window_size)
         return ren, renWin
@@ -1197,7 +1233,7 @@ Inherited from vtk:
         self.ren.AddActor2D(pointLabels)
 
 
-    def plot_xy(self,xd,yd,linespec):
+    def plot_xy(self, xd, yd, linespec, vmin=None, vmax=None):
 
         xVal = vtk.vtkFloatArray()
         yVal = vtk.vtkFloatArray()
@@ -1236,6 +1272,8 @@ Inherited from vtk:
         xyplot.SetTitleTextProperty(text_prop)
         xyplot.SetDataObjectXComponent(0,0)
         xyplot.SetDataObjectYComponent(0,1)
+        if not vmin is None and not vmax is None:
+            xyplot.SetYRange(vmin, vmax)
 
         # determine line style
         if linespec == ".":
