@@ -1,10 +1,25 @@
 #!/usr/bin/env python
 
-__copyright__ = "(C) 2006-2009 Ola Skavhaug and Simula Research Laboratory"
-__license__   = "GNU LGPL Version 2.1."
+# Copyright (C) 2006-2011 Ola Skavhaug and Simula Research Laboratory
+#
+# This file is part of Viper.
+#
+# Viper is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# Viper is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with Viper. If not, see <http://www.gnu.org/licenses/>.
+
 __cite__      = """Ola Skavhaug, Viper Visualization Software,
 http://www.fenicsproject.org"""
-__version__ = "0.4.7"
+__version__ = "1.0.0"
 
 __doc__ = """
 Viper for DOLFIN
@@ -13,11 +28,9 @@ A simple mesh plotter and run--time visualization module for plotting and
 saving simulation data. Adjusted Viper for plotting native DOLFIN data
 structures like dolfin::Mesh, dolfin::MeshFunction, and dolfin::Function.
 
-Copyright: %s
-Licence: %s
 Citation: %s
 
-""" % (__copyright__, __license__, __cite__)
+""" % __cite__
 
 from viper import Viper as ViperBase
 import dolfin
@@ -147,7 +160,9 @@ class Viper(ViperBase):
             (self.iren, self.renWin, self.ren) = self.simple_plotter(self.filter, vmin, vmax, wireframe=wireframe)
         elif self.mode == "scalar_xy":
             xx = self.mesh.coordinates()
-            (self.iren, self.renWin, self.ren) = self.plot_xy(xx,self.x,".-")
+            (self.iren, self.renWin, self.ren) = self.plot_xy(xx, self.x, ".-",
+                                                              vmin=kwargs.get("vmin", None),
+                                                              vmax=kwargs.get("vmax", None))
         elif self.mode in ("vector", "displacement"):
             self.x.shape = (dpn, nno)
             self.x = self.vec3d(self.x.transpose().copy())
@@ -210,7 +225,9 @@ class Viper(ViperBase):
             (self.iren, self.renWin, self.ren) = self.simple_plotter(self.filter, vmin, vmax, wireframe=wireframe)
         elif self.mode == "scalar_xy":
             xx = self.mesh.coordinates()
-            (self.iren, self.renWin, self.ren) = self.plot_xy(xx,self.x,".-")
+            (self.iren, self.renWin, self.ren) = self.plot_xy(xx, self.x, ".-",
+                                                              vmin=kwargs.get("vmin", None),
+                                                              vmax=kwargs.get("vmax", None))
         elif self.mode in ("vector", "displacement"):
             self.x.shape = (dpn, nno)
             self.x = self.vec3d(self.x.transpose().copy())
@@ -315,7 +332,7 @@ class Viper(ViperBase):
 
         self.ren.AddActor(actor)
 
-    def dolfin_update(self, data):
+    def dolfin_update(self, data, **kwargs):
 
         # Prepare data to viper internal format
         if self.plottype == "mesh":
@@ -359,6 +376,10 @@ class Viper(ViperBase):
         else:
             print "Unknown plottype %s. Can't update" % (self.plottype,)
 
+        # Update title if given
+        if 'title' in kwargs:
+            self.title = str(kwargs['title'])
+
         # Plot data
         self._update(self.x)
 
@@ -383,7 +404,7 @@ class PlotManager(object):
     def autoplot(self, plot_object, *args, **kwargs):
         for (idx, (plotter,obj)) in self.plots.items():
             if obj is plot_object:
-                plotter.update(plot_object)
+                plotter.update(plot_object, **kwargs)
                 return plotter
         idx = self.random.randint(0,10000)
         keys = self.plots.keys()
@@ -398,7 +419,7 @@ class PlotManager(object):
     def figureplot(self, plot_object, *args, **kwargs):
         if self.plots.has_key(self.index):
             (plotter, obj) = self.plots[self.index]
-            plotter.update(plot_object)
+            plotter.update(plot_object, **kwargs)
             self.plots[self.index] = (plotter, plot_object)
             return plotter
 
